==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/no/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Bekreft sletting av flere enheter',
  'bulk_delete_help'	=> 'Se gjennom listen over enheter som er valgt for sletting. Etter sletting er det mulig å gjenopprette enheter, men nåværende koblinger til brukere vil ikke lenger finnes.',
  'bulk_delete_warn'	=> 'Du er i ferd med å slette :asset_count enheter.',
	'bulk_update'		=> 'Masseoppdater eiendeler',
	'bulk_update_help'	=> 'Dette skjemaet lar deg oppdatere flere eiendeler på en gang. Fyll kun ut feltene du ønsker å endre. Tomme felter forblir uendret. ',
	'bulk_update_warn'	=> 'Du er på vei til å endre egenskapene til :asset_count eiendeler.',
    'checkedout_to'		=> 'Utsjekket til',
    'checkout_date'		=> 'Utsjekkdato',
    'checkin_date'		=> 'Innsjekkdato',
    'checkout_to'		=> 'Sjekk ut til',
    'cost'				=> 'Innkjøpskostnad',
    'create'			=> 'Opprett eiendel',
    'date'				=> 'Innkjøpsdato',
    'depreciation'	    => 'avskrivninger',
    'depreciates_on'	=> 'Avskrivningstype',
    'default_location'	=> 'Standard plassering',
    'eol_date'			=> 'EOL dato',
    'eol_rate'			=> 'EOL-rate',
    'expected_checkin'  => 'Forventet dato for innsjekk',
    'expires'			=> 'Utløper',
    'fully_depreciated'	=> 'Ferdig nedskrevet',
    'help_checkout'		=> 'Hvis du ønsker å tildele denne eiendelen umiddelbart, velger du "klar til å distribuere" fra status listen ovenfor. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Produsent',
    'model'				=> 'Modell',
    'months'			=> 'måneder',
    'name'				=> 'Navn',
    'notes'				=> 'Notater',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Brukere kan be om eiendel',
    'select_statustype'	=> 'Velg statustype',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Eiendelsmerke',
    'update'			=> 'Oppdater eiendel',
    'warranty'			=> 'Garanti',
		'warranty_expires'		=> 'Garantien utløper',
    'years'				=> 'år',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/no/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekreft sletting av flere enheter',
  'bulk_delete_help'	=> 'Se gjennom listen over enheter som er valgt for sletting. Etter sletting er det mulig å gjenopprette enheter, men nåværende koblinger til brukere vil ikke lenger finnes.',
  'bulk_delete_warn'	=> 'Du er i ferd med å slette :asset_count enheter.',
    'bulk_update'		=> 'Masseoppdater eiendeler',
    'bulk_update_help'	=> 'Dette skjemaet lar deg oppdatere flere eiendeler på en gang. Fyll kun ut feltene du ønsker å endre. Tomme felter forblir uendret. ',
    'bulk_update_warn'	=> 'Du er på vei til å endre egenskapene til :asset_count eiendeler.',
    'checkedout_to'		=> 'Utsjekket til',
    'checkout_date'		=> 'Utsjekkdato',
    'checkin_date'		=> 'Innsjekkdato',
    'checkout_to'		=> 'Sjekk ut til',
    'cost'				=> 'Innkjøpskostnad',
    'create'			=> 'Opprett eiendel',
    'date'				=> 'Innkjøpsdato',
    'depreciation'	    => 'avskrivninger',
    'depreciates_on'	=> 'Avskrivningstype',
    'default_location'	=> 'Standard plassering',
    'eol_date'			=> 'EOL dato',
    'eol_rate'			=> 'EOL-rate',
    'expected_checkin'  => 'Forventet dato for innsjekk',
    'expires'			=> 'Utløper',
    'fully_depreciated'	=> 'Ferdig nedskrevet',
    'help_checkout'		=> 'Hvis du ønsker å tildele denne eiendelen umiddelbart, velger du "klar til å distribuere" fra status listen ovenfor. ',
    'mac_address'		=> 'MAC-adresse',
    'manufacturer'		=> 'Produsent',
    'model'				=> 'Modell',
    'months'			=> 'måneder',
    'name'				=> 'Navn',
    'notes'				=> 'Notater',
    'order'				=> 'Ordrenummer',
    'qr'				=> 'QR-kode',
    'requestable'		=> 'Brukere kan be om eiendel',
    'select_statustype'	=> 'Velg statustype',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Eiendelsmerke',
    'update'			=> 'Oppdater eiendel',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantien utløper',
    'years'				=> 'år',
    'asset_location' => 'Oppdater lokasjon for eiendelen',
    'asset_location_update_default_current' => 'Oppdater standardlokasjon OG faktisk lokasjon',
    'asset_location_update_default' => 'Oppdater bare standardlokasjon',
    'asset_not_deployable' => 'Den eiendelstatusen gjør at denne eiendelen ikke kan sjekkes ut.',
    'asset_deployable' => 'Den statusen gjør det mulig å sjekke ut denne eiendelen.',
    'processing_spinner' => 'Behandler...',
];
